import 'package:deposits_oneclick_checkout/app/common/utils/exports.dart';
import 'package:deposits_oneclick_checkout/app/model/charge_funds_source/charge_funds_response.dart';
import 'package:flutter_dotenv/flutter_dotenv.dart';

PayWithDepositsController controller = Get.put(PayWithDepositsController());
PaymentsController payController = Get.put(PaymentsController());

//initial function to call the deposit buttom
void pay(
  BuildContext context,
  ButtonConfig buttonConfig, {
  Widget? initialScreen,
  required String userEmail,
  required String subClientApiKey,
  ValueChanged<ChargeFundResponse>? chargeFundsResponse,
})async {
  GetStorage.init();
   await dotenv.load(
     fileName: 'packages/deposits_oneclick_checkout/lib/app/common/assets/.env'
   );
  showModalBottomSheet(
      context: context,
      elevation: 4,
      enableDrag: true,
      builder: (context) {
        return PayButtonSheet(
          buttonConfig: buttonConfig,
          userEmail: userEmail,
          subClientApiKey: subClientApiKey,
          initialScreen: initialScreen,
          chargeFundsResponse: chargeFundsResponse,
        );
      }).whenComplete(() {
        chargeFundsResponse!(controller.finalChargeFundResponse);
      });
}

class PayButtonSheet extends StatefulWidget {
  final ButtonConfig buttonConfig;
  final Widget? initialScreen;
  final String userEmail;
  final String subClientApiKey;
  final ValueChanged<ChargeFundResponse>? chargeFundsResponse;
  const PayButtonSheet(
      {Key? key,
      required this.buttonConfig,
      required this.userEmail,
      required this.subClientApiKey,
      this.initialScreen,
      this.chargeFundsResponse})
      : super(key: key);

  @override
  State<PayButtonSheet> createState() => _PayButtonSheetState();
}

class _PayButtonSheetState extends State<PayButtonSheet> {
  @override
  Widget build(BuildContext context) {
    return Container(
        padding:
            const EdgeInsets.only(left: 30, right: 30, top: 15, bottom: 15),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: [
            PayWithDepositsButton(
              buttonConfig: widget.buttonConfig,
              userEmail: widget.userEmail,
              subClientApiKey: widget.subClientApiKey,
              initialScreen: widget.initialScreen,
              chargFundsResponse: widget.chargeFundsResponse,
            ),
            if (Storage.hasData(Constants.isCardAdded)) ...[
              controller.isLoading.isFalse
                  ? Obx(
                      () => Container(
                        margin: const EdgeInsets.only(top: (10)),
                        child: CustomRowTextWidget(
                          title: payController.isPayWithCard.isTrue
                              ? Strings.payWith +
                                  Storage.getValue(Constants.cardNumber)
                              : Strings.payWith +
                                  Storage.getValue(Constants.accountNumber),
                          titleStyle: const TextStyle(color: AppColors.black),
                          titleOnTap: () {},
                          subtitle: Strings.edit,
                          subtitleStyle: const TextStyle(
                              color: AppColors.borderButtonColor),
                          subTitleOnTap: () {
                            // Navigator.of(context, rootNavigator: true).pop();
                            Utils.navigationPush(
                              context,
                              ManageDepositID(
                                  initialScreen: widget.initialScreen),
                              onComplete: () {
                                setState(() {});
                              },
                            );
                          },
                        ),
                      ),
                    )
                  : const SizedBox(),
            ],
            verticalSpaceMedium,
            SvgPicture.asset(AppImages.depositsLogo,
                package: 'deposits_oneclick_checkout'),
            verticalSpaceMedium,
          ],
        ));
  }
}

//pay with deposits button
class PayWithDepositsButton extends StatefulWidget {
  final ButtonConfig buttonConfig;
  final String userEmail;
  final String subClientApiKey;
  final Widget? initialScreen;
  final ValueChanged<ChargeFundResponse>? chargFundsResponse;

  const PayWithDepositsButton(
      {Key? key,
      required this.buttonConfig,
      required this.userEmail,
      required this.subClientApiKey,
      this.initialScreen,
      this.chargFundsResponse});
  @override
  _PayWithDepositsButtonState createState() => _PayWithDepositsButtonState();
}

class _PayWithDepositsButtonState extends State<PayWithDepositsButton> {
  @override
  Widget build(BuildContext context) {
    return ElevatedButton(
        onPressed: () {
          Storage.removeValue(Constants.amountToProcess);
          Storage.saveValue(Constants.amountToProcess,
              widget.buttonConfig.amount.toStringAsFixed(2));
          Storage.saveValue(Constants.userEmail, widget.userEmail);
          Storage.saveValue(Constants.subClientApiKey, widget.subClientApiKey);
          if (Storage.hasData(Constants.isCardAdded)) {
            payController.isPayWithCard.isTrue
                ? controller.payWithCard(context, widget.initialScreen!,widget.chargFundsResponse)
                : controller.payWithBank(context, widget.initialScreen!, widget.chargFundsResponse);
          } else {
            Utils.navigationPush(
                context,
                Login(
                  initialScreen: widget.initialScreen,
                ));
          }
        },
        style: ButtonStyle(
          elevation: MaterialStateProperty.all(0),
          minimumSize: MaterialStateProperty.resolveWith<Size>(
            (states) => Size(
              widget.buttonConfig.minWidth,
              widget.buttonConfig.height,
            ),
          ),
          shape: widget.buttonConfig.addBorder
              ? MaterialStateProperty.resolveWith<RoundedRectangleBorder>(
                  (states) => RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(2),
                    side: BorderSide(
                      color: widget.buttonConfig.buttonColor ==
                              AppColors.activButtonColor
                          ? Colors.white
                          : widget.buttonConfig.buttonBorderColor,
                      width: 2,
                    ),
                  ),
                )
              : MaterialStateProperty.resolveWith<RoundedRectangleBorder>(
                  (states) => RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(4),
                  ),
                ),
          overlayColor: MaterialStateProperty.resolveWith<Color?>(
            (Set<MaterialState> states) {
              if (states.contains(MaterialState.pressed)) {
                return Colors.transparent;
              }

              return null;
            },
          ),
          backgroundColor: MaterialStateProperty.resolveWith<Color>(
            (Set<MaterialState> states) {
              if (states.contains(MaterialState.disabled)) {
                return widget.buttonConfig.buttonColor.withOpacity(.50);
              }
              return !controller.isLoading.value
                  ? widget.buttonConfig.buttonColor
                  : widget.buttonConfig.buttonColor.withOpacity(0.6);
            },
          ),
        ),
        child: Obx(
          () => controller.isLoading.isTrue
              ? SpinKitFadingCircle(
                  color: widget.buttonConfig.loaderColor,
                  size: 20,
                )
              : widget.buttonConfig.titleWidget ??
                  Row(
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: [
                      Text(
                        "Pay \$" +
                            widget.buttonConfig.amount.toStringAsFixed(2) +
                            " USD",
                        style: widget.buttonConfig.textStyle ??
                            AppTextStyle.boldStyle.copyWith(
                              fontSize: Dimens.fontSize14,
                              color: widget.buttonConfig.buttonColor ==
                                          Colors.white ||
                                      widget.buttonConfig.buttonColor ==
                                          Colors.transparent ||
                                      widget.buttonConfig.buttonColor ==
                                          AppColors.declineColor
                                  ? widget.buttonConfig.textColor
                                  : Colors.white,
                            ),
                      ),
                    ],
                  ),
        ));
  }
}

class ButtonConfig {
  final double amount;
  final TextStyle? textStyle;
  final double height, minWidth;
  final Widget? titleWidget;
  final Color buttonColor, buttonBorderColor, textColor, loaderColor;
  final bool addBorder;
  // final bool isBusy;

  const ButtonConfig({
    required this.amount,
    this.textStyle,
    this.height = 55,
    this.minWidth = 100,
    this.buttonColor = AppColors.activButtonColor,
    this.buttonBorderColor = AppColors.borderButtonColor,
    this.textColor = AppColors.black,
    this.loaderColor = AppColors.white,
    this.titleWidget,
    this.addBorder = false,
    // this.isBusy = false,
  });
}
